package com.ruoyi.shipping.domain;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

import com.fasterxml.jackson.annotation.JsonFormat;
import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;
import com.ruoyi.common.annotation.Excel;
import com.ruoyi.common.core.domain.BaseEntity;

/**
 * 海运运价从对象 t_ctnprice_items
 * 
 * @author ruoyi
 * @date 2021-04-06
 */
public class TCtnpriceItems extends BaseEntity
{
    private static final long serialVersionUID = 1L;

    /** 主键 */
    private Long fId;

    /** t_ctnprice id */
    @Excel(name = "t_ctnprice id")
    private Long fPid;

    /** 集装箱id */
    @Excel(name = "集装箱id")
    private Long fCntrid;

    /** 单价 */
    @Excel(name = "单价")
    private BigDecimal fPrice;
    /** 航期 */
    @Excel(name = "航期")
    private String fDates;

    /** 默认 T ,正常T 停用F 下拉选择 */
    @Excel(name = "默认 T ,正常T 停用F 下拉选择")
    private String fStatus;
    //查询时间区间
    private List<String> cLoadDate;
    //集装箱编号
    private String cntridName;
    //起始港
    private Long fPortofloadid;
    //目的港
    private Long fDistinationid;
    //中转港
    private Long fPortoftransshipment;
    /** 预计开船日期 */
    @JsonFormat(pattern = "yyyy-MM-dd")
    private Date fEtd;

    public String getfDates() {
        return fDates;
    }

    public void setfDates(String fDates) {
        this.fDates = fDates;
    }

    public Long getfPortoftransshipment() {
        return fPortoftransshipment;
    }

    public void setfPortoftransshipment(Long fPortoftransshipment) {
        this.fPortoftransshipment = fPortoftransshipment;
    }

    public Date getfEtd() {
        return fEtd;
    }

    public void setfEtd(Date fEtd) {
        this.fEtd = fEtd;
    }

    public Long getfPortofloadid() {
        return fPortofloadid;
    }

    public void setfPortofloadid(Long fPortofloadid) {
        this.fPortofloadid = fPortofloadid;
    }

    public Long getfDistinationid() {
        return fDistinationid;
    }

    public void setfDistinationid(Long fDistinationid) {
        this.fDistinationid = fDistinationid;
    }

    public String getCntridName() {
        return cntridName;
    }

    public void setCntridName(String cntridName) {
        this.cntridName = cntridName;
    }

    public List<String> getcLoadDate() {
        return cLoadDate;
    }

    public void setcLoadDate(List<String> cLoadDate) {
        this.cLoadDate = cLoadDate;
    }

    public void setfId(Long fId)
    {
        this.fId = fId;
    }

    public Long getfId() 
    {
        return fId;
    }
    public void setfPid(Long fPid) 
    {
        this.fPid = fPid;
    }

    public Long getfPid() 
    {
        return fPid;
    }
    public void setfCntrid(Long fCntrid) 
    {
        this.fCntrid = fCntrid;
    }

    public Long getfCntrid() 
    {
        return fCntrid;
    }
    public void setfPrice(BigDecimal fPrice) 
    {
        this.fPrice = fPrice;
    }

    public BigDecimal getfPrice() 
    {
        return fPrice;
    }
    public void setfStatus(String fStatus) 
    {
        this.fStatus = fStatus;
    }

    public String getfStatus() 
    {
        return fStatus;
    }

    @Override
    public String toString() {
        return new ToStringBuilder(this,ToStringStyle.MULTI_LINE_STYLE)
            .append("fId", getfId())
            .append("fPid", getfPid())
            .append("fCntrid", getfCntrid())
            .append("fPrice", getfPrice())
            .append("fStatus", getfStatus())
            .append("createBy", getCreateBy())
            .append("createTime", getCreateTime())
            .append("updateBy", getUpdateBy())
            .append("updateTime", getUpdateTime())
            .append("remark", getRemark())
            .append("fDates", getfDates())
                .toString();
    }
}
